@@ -1,6 +1,6 @@
 =head1 NAME
 
-Date::Tolkien::Shire - Convert dates into the Shire Calendar.
+Date::Tolkien::Shire.pm
 
 =head1 DESCRIPTION
 
@@ -20,25 +20,9 @@ am curious to see how this gets used (if it gets used that is).
 
 Tom Braun <tbraun@pobox.com>
 
-Thomas R. Wyant, III F<wyant at cpan dot org>
+=head1 DATE
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (c) 2001-2003, 2006 Tom Braun. All rights reserved.
-
-Copyright (C) 2017 Thomas R. Wyant, III
-
-The calendar implemented on this module was created by J.R.R. Tolkien,
-and the copyright is still held by his estate.  The license and
-copyright given herein applies only to this code and not to the
-calendar itself.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-This program is distributed in the hope that it will be useful, but
-without any warranty; without even the implied warranty of
-merchantability or fitness for a particular purpose.
+February 2001
 
 =cut
 
@@ -49,7 +33,7 @@ use Time::Local;
 
 use vars qw($VERSION $ERROR);
 
-$VERSION = '1.19_02';
+$VERSION = 1.01;
 
 =head1 METHOD REFERENCE
 
@@ -186,11 +170,11 @@ sub set_date {
 	#leap year can now be ignored for the rest of this
 	#now check for any of the other holidays
 	unless ($self->{holiday}) {
-	    if ($yday == 356) {$self->{holiday} = 1;} #2 Yule-first day of new year
-	    elsif ($yday == 172) {$self->{holiday} = 2;} #1 Lithe
+	    if ($yday == 356) {$self->{holiday} = 1;} #Yule 2-first day of new year
+	    elsif ($yday == 172) {$self->{holiday} = 2;} #Lithe 1
 	    elsif ($yday == 173) {$self->{holiday} = 3;} #Midyear's day
-	    elsif ($yday == 174) {$self->{holiday} = 5;} #2 Lithe
-	    elsif ($yday == 355) {$self->{holiday} = 6;} #1 Yule
+	    elsif ($yday == 174) {$self->{holiday} = 5;} #Lithe 2
+	    elsif ($yday == 355) {$self->{holiday} = 6;} #Yule 1
 	} #end unless
 
 	#now compute the day of the week.  
@@ -200,7 +184,7 @@ sub set_date {
 	    $self->{weekday} = 0;
 	} #end if
 	else {
-	    $self->{weekday} = (($yday + 2) % 7) + 1;
+	    $self->{weekday} = ($yday % 7) + 1;
 	} #end else
 
 	#Now figure out the month and day of the month
@@ -210,7 +194,7 @@ sub set_date {
 	    $self->{monthday} = 0;
 	} #end if
 	else {
-	    --$yday; #ignore 2 Yule
+	    --$yday; #ignore Yule 2
 	    $yday -= 2 if $yday > 172; #ignore the Lithes (correct plural???)
 	    $yday += 9; #account for different start of year
 	    $yday -= 362 if ($yday > 361);		
@@ -419,16 +403,16 @@ sub day {
     $holiday = $shiredate->holiday;
 
 If the day in question is a holiday, returns a string which holiday it is:
-"1 Yule", "2 Yule" (first day of the new year), "1 Lithe", "Midyear's day",
-"Overlithe", or "2 Lithe".  If the day is not a holiday, the null string
+"Yule 1", "Yule 2" (first day of the new year), "Lithe 1", "Midyear's day",
+"Overlithe", or "Lithe 2".  If the day is not a holiday, the null string
 is returned
 
 =cut
 
 sub holiday {
     my $self = shift;
-    my @holidays = ('', '2 Yule', '1 Lithe', "Midyear's day", 'Overlithe',
-		    '2 Lithe', '1 Yule');
+    my @holidays = ('', 'Yule 2', '1 Lithe', "Midyear's day", 'Overlithe',
+		    'Lithe 2', 'Yule 1');
     $ERROR = '';
     if (defined $self->{holiday}) {
 	return $holidays[$self->{holiday}];
@@ -585,7 +569,7 @@ sub on_date {
     # the day matches up
     $events{0} = { 3  => "Wedding of King Elessar and Arwen, 1419.\n"
 		   };
-    $events{1} = { 8  => "The Company of the Ring reaches Hollin, 1419.\n",
+    $events{1} = { 8  => "The Company of the Ring reaches Holland, 1419.\n",
 		   13 => "The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.\n",
 		   14 => "The Company of the Ring spends the night in Moria hall 21, 1419.\n",
 		   15 => "The Bridge of Khazad-dum, and the fall of Gandalf, 1419.\n",
@@ -599,15 +583,15 @@ sub on_date {
 		   16 => "Company of the Ring says farewell to Lorien --\n" . 
 		       "Gollum observes departure, 1419.\n",
 		   17 => "Gwaihir the eagle bears Gandalf to Lorien, 1419.\n",
-		   25 => "The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.\n" .
+		   23 => "The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.\n" .
 		       "First battle of the Fords of Isen -- Theodred son of Theoden slain, 1419.\n",
-		   26 => "Breaking of the Fellowship, 1419.\n" .
+		   25 => "Breaking of the Fellowship, 1419.\n" .
 		       "Death of Boromir; his horn is heard in Minas Tirith, 1419.\n" .
 		       "Meriadoc and Peregrin captured by Orcs -- Aragorn pursues, 1419.\n" .
-		       "Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.\n" .
+		       "Eomer hears of the descent of the Orc-band from Emyn Muil, 1418.\n" .
 		       "Frodo and Samwise enter the eastern Emyn Muil, 1419.\n",
 		   27 => "Aragorn reaches the west-cliff at sunrise, 1419.\n" .
-		       "Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.\n",
+		       "Eomer sets out Eastfold against Theoden's orders to pursue the Orcs, 1419.\n",
 		   28 => "Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.\n",
 		   29 => "Meriodoc and Pippin escape and meet Treebeard, 1419.\n" .
 		       "The Rohirrim attack at sunrise and destroy the Orcs, 1419.\n" .
@@ -641,7 +625,7 @@ sub on_date {
 		   11 => "Gollum visits Shelob, 1419.\n" . 
 		       "Denethor sends Faramir to Osgiliath, 1419.\n" .
 		       "Eastern Rohan is invaded and Lorien assaulted, 1419.\n",
-		   12 => "Gollum leads Frodo into Shelob's lair, 1419.\n" .
+		   12 => "Gollum leads Frodo in Shelob's lair, 1419.\n" .
 		       "Ents defeat the invaders of Rohan, 1419.\n",
 		   13 => "Frodo captured by the Orcs of Cirith Ungol, 1419.\n" .
 		       "The Pelennor is overrun and Faramir is wounded, 1419.\n" .
@@ -668,7 +652,7 @@ sub on_date {
 		   27 => "Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.\n",
 		   28 => "Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.\n"
 		   };
-    $events{4} = { 6  => "The mallorn tree flowers in the party field, 1420.\n",
+    $events{4} = { 6  => "The mallorn trea flowers in the party field, 1420.\n",
 	           8  => "Ring bearers are honored on the fields of Cormallen, 1419.\n",
 	           12 => "Gandalf arrives in Hobbiton, 1418\n"
 	           };
@@ -685,7 +669,7 @@ sub on_date {
     $events{8} = { 10 => "Funeral of King Theoden, 1419.\n"
 		   };
     $events{9} = { 18 => "Gandalf escapes from Orthanc in the early hours, 1418.\n",
-		   19 => "Gandalf comes to Edoras as a beggar, and is refused admittance, 1418",
+		   19 => "Gandalf comes to Edoras as a beggar, and is refused admintance, 1418",
 		   20 => "Gandalf gains entrance to Edoras.  Theoden commands him to go:\n" .
 		       "\"Take any horse, only be gone ere tomorrow is old\", 1418.\n",
 		   21 => "The hobbits return to Rivendell, 1419.\n",
@@ -694,7 +678,7 @@ sub on_date {
 		       "  they drive off the guard of Rangers, 1418.\n" .
 		       "Saruman comes to the Shire, 1419.\n",   
 		   23 => "Four Black Riders enter the shire before dawn.  The others pursue \n" .
-		       "the Rangers eastward and then return to watch the Greenway, 1418.\n" .
+		       "the Rangers eastword and then return to watch the Greenway, 1418.\n" .
 		       "A Black Rider comes to Hobbiton at nightfall, 1418.\n" . 
 		       "Frodo leaves Bag End, 1418.\n" .
 		       "Gandalf having tamed Shadowfax rides from Rohan, 1418.\n",
@@ -708,7 +692,7 @@ sub on_date {
             	   };
     $events{10} = { 3  => "Gandalf attacked at night on Weathertop, 1418.\n",
 		    5  => "Gandalf and the Hobbits leave Rivendell, 1419.\n",
-		    6  => "The camp under Weathertop is attacked at night and Frodo is wounded, 1418.\n",
+		    6  => "The camp under weathertop is attacked at night and Frodo is wounded, 1418.\n",
 		    11 => "Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.\n",
 		    13 => "Frodo crosses the Bridge of Mitheithel, 1418.\n",
 		    18 => "Glorfindel finds Frodo at dusk, 1418.\n" . 
@@ -782,5 +766,3 @@ support on your system.
 =cut
 
 1;
-
-# ex: set textwidth=72 :
